@@ -2,10 +2,11 @@ package MooseX::Role::Parameterized::Meta::Role::Parameterizable;
 use Moose;
 extends 'Moose::Meta::Role';
 
-our $VERSION = '0.27';
+our $VERSION = '1.01';
 
 use MooseX::Role::Parameterized::Meta::Role::Parameterized;
 use MooseX::Role::Parameterized::Parameters;
+use Module::Runtime 'use_module';
 
 has parameterized_role_metaclass => (
     is      => 'ro',
@@ -57,7 +58,7 @@ sub generate_role {
         unless $self->has_role_generator;
 
     my $parameterized_role_metaclass = $self->parameterized_role_metaclass;
-    Class::MOP::load_class($parameterized_role_metaclass);
+    use_module($parameterized_role_metaclass);
 
     my $role;
     if ($args{package}) {
